==========
To-do List
==========

Advantages of SEO:
------------------

#. Attach meta data to any object in a standard, centralised way  (*)
#. Edit meta data in a single place in Admin (*)
#. Sanitise and escape admin user data appropriately (**)
#. Attach meta data to any path (**)
#. Attach meta data to any view  (***)
#. Allow custom meta data to be deployed universally across site (***)

(*)   Convenient, often done anyway
(**)  Very useful, rarely done properly
(***) Extremely useful, almost never done
